@@ -38,7 +38,7 @@ static gint handle_command_line (GApplication *application, GApplicationCommandL
 typedef struct {
 	/* Command line parameters. */
 	gboolean debug;
-	gint seed;
+	guint seed;
 } HitoriApplicationPrivate;
 
 typedef enum {
@@ -69,10 +69,10 @@ hitori_application_class_init (HitoriApplicationClass *klass)
 	                                                       G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 	g_object_class_install_property (gobject_class, PROP_SEED,
-	                                 g_param_spec_int ("seed",
-	                                                   "Generation Seed", "Seed controlling generation of the board.",
-	                                                   G_MININT, G_MAXINT, -1,
-	                                                   G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+	                                 g_param_spec_uint ("seed",
+	                                                    "Generation Seed", "Seed controlling generation of the board.",
+	                                                    0, G_MAXUINT, 0,
+	                                                    G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -83,7 +83,7 @@ hitori_application_init (HitoriApplication *self)
 	priv = hitori_application_get_instance_private (self);
 
 	priv->debug = FALSE;
-	priv->seed = -1;
+	priv->seed = 0;
 }
 
 static void
@@ -117,7 +117,7 @@ get_property (GObject *object, guint property_id, GValue *value, GParamSpec *psp
 			g_value_set_boolean (value, priv->debug);
 			break;
 		case PROP_SEED:
-			g_value_set_int (value, priv->seed);
+			g_value_set_uint (value, priv->seed);
 			break;
 		default:
 			/* We don't have any other property... */
@@ -138,7 +138,7 @@ set_property (GObject *object, guint property_id, const GValue *value, GParamSpe
 			priv->debug = g_value_get_boolean (value);
 			break;
 		case PROP_SEED:
-			priv->seed = g_value_get_int (value);
+			priv->seed = g_value_get_uint (value);
 			break;
 		default:
 			/* We don't have any other property... */
@@ -180,7 +180,9 @@ activate (GApplication *application)
 
 	/* Create the interface. */
 	if (self->window == NULL) {
+		GdkRectangle geometry;
 		HitoriUndo *undo;
+		gboolean window_maximized;
 		gchar *size_str;
 
 		/* Setup */
@@ -190,6 +192,15 @@ activate (GApplication *application)
 		self->board_size = g_ascii_strtoull (size_str, NULL, 10);
 		g_free (size_str);
 
+		if (self->board_size > MAX_BOARD_SIZE) {
+			GVariant *default_size = g_settings_get_default_value (self->settings, "board-size");
+			g_variant_get (default_size, "s", &size_str);
+			g_variant_unref (default_size);
+			self->board_size = g_ascii_strtoull (size_str, NULL, 10);
+			g_free (size_str);
+			g_assert (self->board_size <= MAX_BOARD_SIZE);
+		}
+
 		undo = g_new0 (HitoriUndo, 1);
 		undo->type = UNDO_NEW_GAME;
 		self->undo_stack = undo;
@@ -198,6 +209,30 @@ activate (GApplication *application)
 		hitori_create_interface (self);
 		hitori_generate_board (self, self->board_size, priv->seed);
 
+		/* Restore window position and size */
+		window_maximized = g_settings_get_boolean (self->settings,
+																							 "window-maximized");
+		g_settings_get (self->settings,
+										"window-position", "(ii)",
+										&geometry.x, &geometry.y);
+		g_settings_get (self->settings,
+										"window-size", "(ii)",
+										&geometry.width, &geometry.height);
+
+		if (window_maximized) {
+			gtk_window_maximize (GTK_WINDOW (self->window));
+		} else {
+			if (geometry.x > -1 && geometry.y > -1) {
+				gtk_window_move (GTK_WINDOW (self->window),
+												 geometry.x, geometry.y);
+			}
+
+			if (geometry.width >= 0 && geometry.height >= 0) {
+				gtk_window_resize (GTK_WINDOW (self->window),
+													 geometry.width, geometry.height);
+			}
+		}
+
 		gtk_window_set_application (GTK_WINDOW (self->window), GTK_APPLICATION (self));
 		gtk_widget_show_all (self->window);
 	}
@@ -267,7 +302,7 @@ hitori_new_game (Hitori *hitori, guint board_size)
 {
 	hitori->made_a_move = FALSE;
 
-	hitori_generate_board (hitori, board_size, -1);
+	hitori_generate_board (hitori, board_size, 0);
 	hitori_clear_undo_stack (hitori);
 	gtk_widget_queue_draw (hitori->drawing_area);
 
